==> remotable-plugins-plugin-0.6.996.jar: js/iframe-min/rpc-min.js <==
(function(k,l,n,j,a,d){var o=k.AP||k._AP,f=o._$||(k.AJS&&AJS.$)||k.jQuery,i=k.location.toString();
o._Rpc=function(r,p){var A={},x,z,y,q=p.local||{},w=p.remote||[];
var v=function(){function B(){var C={};
return function(E,D){if(typeof D==="function"){C[E]=D
}else{if(C[E]){C[E](D);
delete C[E]
}}}
}return{done:B(),fail:B()}
}();
if(!/xdm_e/.test(i)){var u=m(r);
x=u.contentWindow;
z=h(r.remote);
y=r.channel;
A.destroy=function(){}
}else{x=k.parent;
z=c(i,"xdm_e");
y=c(i,"xdm_c")
}function t(E,C,D){try{x.postMessage(n.stringify({c:y,i:E,t:C,m:D}),z)
}catch(B){e(g(B))
}}function s(I){try{var M=n.parse(I.data),G=M.i,H=M.c,P=M.t,N=M.m;
if(I.source!==x||I.origin!==z||H!==y){return
}if(P==="request"){var B=N.n,K=N.a,L=q[B],F,C,D;
if(L){function E(Q){return function(R){t(G,Q,R)
}
}F=E("done");
C=E("fail");
D=(K?K.length:0)<L.length;
try{if(D){L.apply(q,K.concat([F,C]))
}else{F(L.apply(q,K))
}}catch(J){C(g(J))
}}else{e("Unhandled request:",M)
}}else{if(P==="done"||P==="fail"){var O=v[P];
if(O){O(G,N)
}else{e("Unhandled response:",M)
}}}}catch(J){e(g(J))
}}f.each(w,function(C,B){if(typeof C==="number"){C=B
}A[C]=function(){var F=[].slice.call(arguments),E,D;
function G(){if(typeof F[F.length-1]==="function"){return F.pop()
}}D=G();
E=G();
if(!E){E=D;
D=d
}var H=Math.floor(Math.random()*1000000000).toString(16);
if(E){v.done(H,E)
}if(D){v.fail(H,D)
}t(H,"request",{n:C,a:F})
}
});
f(k).bind("message",function(B){s(B.originalEvent?B.originalEvent:B)
});
return A
};
function c(q,p){return a(RegExp(p+"=([^&]+)").exec(q)[1])
}function h(r){var p=r.toLowerCase().match(/^((http.?:)\/\/([^:\/\s]+)(:\d+)*)/),s=p[2],t=p[3],q=p[4]||"";
if((s==="http:"&&q===":80")||(s==="https:"&&q===":443")){q=""
}return s+"//"+t+q
}function b(r,s){var q=r,p=/\?/.test(r)?"&":"?";
f.each(s,function(u,t){q+=p+j(u)+"="+j(t);
p="&"
});
return q
}function m(q){var r=l.createElement("iframe");
var t="easyXDM_"+q.container+"_provider";
var s=b(q.remote,{xdm_e:h(i),xdm_c:q.channel,xdm_p:1});
f.extend(r,{id:t,name:t,frameBorder:"0"},q.props);
var p=f("#"+q.container)[0];
p.appendChild(r);
r.src=s;
return r
}function g(p){return p.message||p.toString()
}function e(){if(k.console){console.log.apply(console,arguments)
}}}(this,document,JSON,encodeURIComponent,decodeURIComponent));

==> remotable-plugins-plugin-0.7.1016.jar: js/iframe-min/rpc-min.js <==
(function(k,l,n,j,a,d){var o=k._AP||k.AP,f=o._$||(k.AJS&&AJS.$)||k.jQuery,i=k.location.toString();
o._Rpc=function(r,p){var A={},x,z,y,q=p.local||{},w=p.remote||[];
var v=function(){function B(){var C={};
return function(E,D){if(typeof D==="function"){C[E]=D
}else{if(C[E]){C[E](D);
delete C[E]
}}}
}return{done:B(),fail:B()}
}();
if(!/xdm_e/.test(i)){var u=m(r);
x=u.contentWindow;
z=h(r.remote);
y=r.channel;
A.destroy=function(){}
}else{x=k.parent;
z=c(i,"xdm_e");
y=c(i,"xdm_c")
}function t(E,C,D){try{x.postMessage(n.stringify({c:y,i:E,t:C,m:D}),z)
}catch(B){e(g(B))
}}function s(I){try{var M=n.parse(I.data),G=M.i,H=M.c,P=M.t,N=M.m;
if(I.source!==x||I.origin!==z||H!==y){return
}if(P==="request"){var B=N.n,K=N.a,L=q[B],F,C,D;
if(L){function E(Q){return function(R){t(G,Q,R)
}
}F=E("done");
C=E("fail");
D=(K?K.length:0)<L.length;
try{if(D){L.apply(q,K.concat([F,C]))
}else{F(L.apply(q,K))
}}catch(J){C(g(J))
}}else{e("Unhandled request:",M)
}}else{if(P==="done"||P==="fail"){var O=v[P];
if(O){O(G,N)
}else{e("Unhandled response:",M)
}}}}catch(J){e(g(J))
}}f.each(w,function(C,B){if(typeof C==="number"){C=B
}A[C]=function(){var F=[].slice.call(arguments),E,D;
function G(){if(typeof F[F.length-1]==="function"){return F.pop()
}}D=G();
E=G();
if(!E){E=D;
D=d
}var H=Math.floor(Math.random()*1000000000).toString(16);
if(E){v.done(H,E)
}if(D){v.fail(H,D)
}t(H,"request",{n:C,a:F})
}
});
f(k).bind("message",function(B){s(B.originalEvent?B.originalEvent:B)
});
return A
};
function c(q,p){return a(RegExp(p+"=([^&]+)").exec(q)[1])
}function h(r){var p=r.toLowerCase().match(/^((http.?:)\/\/([^:\/\s]+)(:\d+)*)/),s=p[2],t=p[3],q=p[4]||"";
if((s==="http:"&&q===":80")||(s==="https:"&&q===":443")){q=""
}return s+"//"+t+q
}function b(r,s){var q=r,p=/\?/.test(r)?"&":"?";
f.each(s,function(u,t){q+=p+j(u)+"="+j(t);
p="&"
});
return q
}function m(q){var r=l.createElement("iframe");
var t="easyXDM_"+q.container+"_provider";
var s=b(q.remote,{xdm_e:h(i),xdm_c:q.channel,xdm_p:1});
f.extend(r,{id:t,name:t,frameBorder:"0"},q.props);
var p=f("#"+q.container)[0];
p.appendChild(r);
r.src=s;
return r
}function g(p){return p.message||p.toString()
}function e(){if(k.console){console.log.apply(console,arguments)
}}}(this,document,JSON,encodeURIComponent,decodeURIComponent));
